( cd usr/lib/X11/icons/jimmac/cursors ; rm -rf arrow )
( cd usr/lib/X11/icons/jimmac/cursors ; ln -sf right_ptr arrow )
( cd usr/lib/X11/icons/jimmac/cursors ; rm -rf draft_large )
( cd usr/lib/X11/icons/jimmac/cursors ; ln -sf right_ptr draft_large )
( cd usr/lib/X11/icons/jimmac/cursors ; rm -rf draft_small )
( cd usr/lib/X11/icons/jimmac/cursors ; ln -sf right_ptr draft_small )
( cd usr/lib/X11/icons/jimmac/cursors ; rm -rf top_left_arrow )
( cd usr/lib/X11/icons/jimmac/cursors ; ln -sf left_ptr top_left_arrow )
( cd usr/lib/X11/icons/jimmac/cursors ; rm -rf 08e8e1c95fe2fc01f976f1e063a24ccd )
( cd usr/lib/X11/icons/jimmac/cursors ; ln -sf left_ptr_watch 08e8e1c95fe2fc01f976f1e063a24ccd )
( cd usr/lib/X11/icons/jimmac/cursors ; rm -rf 00008160000006810000408080010102 )
( cd usr/lib/X11/icons/jimmac/cursors ; ln -sf sb_v_double_arrow 00008160000006810000408080010102 )
( cd usr/lib/X11/icons/jimmac/cursors ; rm -rf 028006030e0e7ebffc7f7070c0600140 )
( cd usr/lib/X11/icons/jimmac/cursors ; ln -sf sb_h_double_arrow 028006030e0e7ebffc7f7070c0600140 )
( cd usr/lib/X11/icons/jimmac/cursors ; rm -rf 03b6e0fcb3499374a867c041f52298f0 )
( cd usr/lib/X11/icons/jimmac/cursors ; ln -sf crossed_circle 03b6e0fcb3499374a867c041f52298f0 )
( cd usr/lib/X11/icons/jimmac/cursors ; rm -rf 14fef782d02440884392942c11205230 )
( cd usr/lib/X11/icons/jimmac/cursors ; ln -sf sb_h_double_arrow 14fef782d02440884392942c11205230 )
( cd usr/lib/X11/icons/jimmac/cursors ; rm -rf 2870a09082c103050810ffdffffe0204 )
( cd usr/lib/X11/icons/jimmac/cursors ; ln -sf sb_v_double_arrow 2870a09082c103050810ffdffffe0204 )
( cd usr/lib/X11/icons/jimmac/cursors ; rm -rf 3ecb610c1bf2410f44200f48c40d3599 )
( cd usr/lib/X11/icons/jimmac/cursors ; ln -sf left_ptr_watch 3ecb610c1bf2410f44200f48c40d3599 )
( cd usr/lib/X11/icons/jimmac/cursors ; rm -rf 4498f0e0c1937ffe01fd06f973665830 )
( cd usr/lib/X11/icons/jimmac/cursors ; ln -sf fleur 4498f0e0c1937ffe01fd06f973665830 )
( cd usr/lib/X11/icons/jimmac/cursors ; rm -rf 6407b0e94181790501fd1e167b474872 )
( cd usr/lib/X11/icons/jimmac/cursors ; ln -sf copy 6407b0e94181790501fd1e167b474872 )
( cd usr/lib/X11/icons/jimmac/cursors ; rm -rf 640fb0e74195791501fd1ed57b41487f )
( cd usr/lib/X11/icons/jimmac/cursors ; ln -sf hand1 640fb0e74195791501fd1ed57b41487f )
( cd usr/lib/X11/icons/jimmac/cursors ; rm -rf 9d800788f1b08800ae810202380a0822 )
( cd usr/lib/X11/icons/jimmac/cursors ; ln -sf hand1 9d800788f1b08800ae810202380a0822 )
( cd usr/lib/X11/icons/jimmac/cursors ; rm -rf c7088f0f3e6c8088236ef8e1e3e70000 )
( cd usr/lib/X11/icons/jimmac/cursors ; ln -sf bd_double_arrow c7088f0f3e6c8088236ef8e1e3e70000 )
( cd usr/lib/X11/icons/jimmac/cursors ; rm -rf d9ce0ab605698f320427677b458ad60b )
( cd usr/lib/X11/icons/jimmac/cursors ; ln -sf question_arrow d9ce0ab605698f320427677b458ad60b )
( cd usr/lib/X11/icons/jimmac/cursors ; rm -rf e29285e634086352946a0e7090d73106 )
( cd usr/lib/X11/icons/jimmac/cursors ; ln -sf hand2 e29285e634086352946a0e7090d73106 )
( cd usr/lib/X11/icons/jimmac/cursors ; rm -rf fcf1c3c7cd4491d801f1e1c78f100000 )
( cd usr/lib/X11/icons/jimmac/cursors ; ln -sf fd_double_arrow fcf1c3c7cd4491d801f1e1c78f100000 )
( cd usr/lib/X11/icons/jimmac/cursors ; rm -rf crosshair )
( cd usr/lib/X11/icons/jimmac/cursors ; ln -sf X_cursor crosshair )
( cd usr/lib/X11/icons/jimmac/cursors ; rm -rf hand )
( cd usr/lib/X11/icons/jimmac/cursors ; ln -sf hand1 hand )
